BlockPos

Struct BlockPos 

pub struct BlockPos(pub IVec3);
A block position.

Tuple Fields

0: IVec3

Implementations

Source

impl BlockPos

pub const ZERO: BlockPos

pub const MAX_HORIZONTAL_COORDINATE: i32

Maximum horizontal coordinate value: (1 << 26) / 2 - 1 = 33554431

pub const fn new(x: i32, y: i32, z: i32) -> Self

Creates a new BlockPos from coordinates.

pub const fn offset(&self, dx: i32, dy: i32, dz: i32) -> Self

Returns a new BlockPos offset by the given amounts.

pub const fn x(&self) -> i32

Returns the x coordinate.

pub const fn y(&self) -> i32

Returns the y coordinate.

pub const fn z(&self) -> i32

Returns the z coordinate.

pub const fn above(&self) -> Self

Returns the position one block above (Y + 1).

pub const fn above_n(&self, n: i32) -> Self

Returns the position n blocks above (Y + n).

pub const fn below(&self) -> Self

Returns the position one block below (Y - 1).

pub const fn below_n(&self, n: i32) -> Self

Returns the position n blocks below (Y - n).

pub const fn north(&self) -> Self

Returns the position one block to the north (Z - 1).

pub const fn north_n(&self, n: i32) -> Self

Returns the position n blocks to the north (Z - n).

pub const fn south(&self) -> Self

Returns the position one block to the south (Z + 1).

pub const fn south_n(&self, n: i32) -> Self

Returns the position n blocks to the south (Z + n).

pub const fn west(&self) -> Self

Returns the position one block to the west (X - 1).

pub const fn west_n(&self, n: i32) -> Self

Returns the position n blocks to the west (X - n).

pub const fn east(&self) -> Self

Returns the position one block to the east (X + 1).

pub const fn east_n(&self, n: i32) -> Self

Returns the position n blocks to the east (X + n).

pub const fn relative(self, direction: Direction) -> Self

Returns the position offset by one block in the given direction.

pub const fn relative_n(&self, direction: Direction, n: i32) -> Self

Returns the position offset by n blocks in the given direction.

pub const fn relative_axis(&self, axis: Axis, n: i32) -> Self

Returns the position offset by n blocks along the given axis.

pub const fn at_y(&self, y: i32) -> Self

Returns a new position with the same X and Z but the given Y.

pub const fn multiply(&self, factor: i32) -> Self

Returns a new position with all coordinates multiplied by the given factor.

pub fn get_center(&self) -> (f64, f64, f64)

Returns the center of this block as a floating-point position.

pub fn get_bottom_center(&self) -> (f64, f64, f64)

Returns the bottom center of this block (center of the bottom face).

pub const fn containing(x: f64, y: f64, z: f64) -> Self

Creates a BlockPos containing the given floating-point coordinates.

pub const fn min(a: BlockPos, b: BlockPos) -> Self

Returns the minimum coordinates of two positions.

pub const fn max(a: BlockPos, b: BlockPos) -> Self

Returns the maximum coordinates of two positions.