pub struct BlockStateId(pub u16);Expand description
A raw block state id. Using the registry this id can be derived into a block and it’s current properties.
Tuple Fields
0: u16Trait Implementations
Sourceimpl Clone for BlockStateId
impl Clone for BlockStateId
Sourcefn clone(&self) -> BlockStateId
fn clone(&self) -> BlockStateId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BlockStateId
Sourceimpl Debug for BlockStateId
impl Debug for BlockStateId
Sourceimpl Default for BlockStateId
impl Default for BlockStateId
Sourcefn default() -> BlockStateId
fn default() -> BlockStateId
Returns the “default value” for a type. Read more
impl Eq for BlockStateId
Sourceimpl Hash for BlockStateId
impl Hash for BlockStateId
Sourceimpl PartialEq for BlockStateId
impl PartialEq for BlockStateId
Sourcefn eq(&self, other: &BlockStateId) -> bool
fn eq(&self, other: &BlockStateId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ReadFrom for BlockStateId
impl ReadFrom for BlockStateId
impl StructuralPartialEq for BlockStateId