pub struct Identifier {
pub namespace: Cow<'static, str>,
pub path: Cow<'static, str>,
}Expand description
An identifier used by Minecraft.
Fields
namespace: Cow<'static, str>The namespace of the identifier.
path: Cow<'static, str>The path of the identifier.
Implementations
Sourceimpl Identifier
impl Identifier
Sourcepub const VANILLA_NAMESPACE: &'static str = "minecraft"
pub const VANILLA_NAMESPACE: &'static str = "minecraft"
The vanilla namespace.
Sourcepub fn new(
namespace: impl Into<Cow<'static, str>>,
path: impl Into<Cow<'static, str>>,
) -> Self
pub fn new( namespace: impl Into<Cow<'static, str>>, path: impl Into<Cow<'static, str>>, ) -> Self
Creates a new Identifier with the given namespace and path.
pub const fn new_static(namespace: &'static str, path: &'static str) -> Self
Sourcepub const fn vanilla(path: String) -> Self
pub const fn vanilla(path: String) -> Self
Creates a new Identifier with the vanilla namespace.
Sourcepub const fn vanilla_static(path: &'static str) -> Self
pub const fn vanilla_static(path: &'static str) -> Self
Creates a new Identifier with the vanilla namespace and a static path.
Sourcepub const fn valid_namespace_char(char: char) -> bool
pub const fn valid_namespace_char(char: char) -> bool
Returns whether the character is a valid namespace character.
Sourcepub const fn valid_char(char: char) -> bool
pub const fn valid_char(char: char) -> bool
Returns whether the character is a valid path character.
Sourcepub fn validate_namespace(namespace: &str) -> bool
pub fn validate_namespace(namespace: &str) -> bool
Returns whether the namespace is valid.
Sourcepub fn validate_path(path: &str) -> bool
pub fn validate_path(path: &str) -> bool
Returns whether the path is valid.